local M = {}
function M.extractExtension(path)
  local nameWithExtension = M.extract(path):reverse()
  local extensionEnd = nameWithExtension:find(".",nil, true)-1   
  local extensionInverted = nameWithExtension:sub(0,extensionEnd)
  local extension = extensionInverted:reverse()
  -- print("path "..path.."=>"..nameWithExtension.."=>("..fileNameStart..")"..name)
  return extension
end
function M.extractName(path)
    local nameWithExtension = M.extract(path):reverse()
    local fileNameStart = nameWithExtension:find(".",nil, true)+1   
    local nameInverted = nameWithExtension:sub(fileNameStart)
    local name = nameInverted:reverse()
    -- print("path "..path.."=>"..nameWithExtension.."=>("..fileNameStart..")"..name)
    return name
end

function M.extract(path)
  local fileNameBack  = path:reverse()    
  local fileNameEnd = fileNameBack:find("/")
  if not fileNameEnd then
    return path
  else
    local nameInverted = fileNameBack:sub(1, fileNameEnd-1)
    local name = nameInverted:reverse()
    return name
  end
end

function M.forChildPaths(parentPath, handler, filter)
  if type(filter)=="string" then
    local originalFilter = filter
    filter = function(path) 
      return path:match(originalFilter)~=nil; 
    end
  elseif type(filter)~="function" then  
    filter = function() return true; end  
  end
  for i, childName in ipairs(love.filesystem.getDirectoryItems(parentPath)) do
    
    local childPath = parentPath.."/"..childName
    if filter(childName) then
      handler(childPath)
    end
  end
end


function M.getModsRoot()
  return "assets/mods";
end

function M.getSavesRoot()    
  return "assets/saves";
end

function M.getChunksRoot()
  local result =  M.getSavesRoot().."/chunks"
  love.filesystem.createDirectory(result)
  return result
end

function M.pathToId(path)
  local prefix = M.getModsRoot()
  if path:find(prefix) then
    path = path:sub(prefix:len()+1)
  end
  local suffix = M.extractExtension(path)
  if suffix then
    path = path:sub(1, path:len()-suffix:len())
  end
  path = path:gsub("/",":")
  return path
end

function M.getChunkFileNameById(chunkId)
  return M.getChunksRoot().."/"..chunkId..".txt"
end



return M